---
name: Bug report
about: Create a bug report to help us eliminate issues and improve dpgen. If this
  doesn’t look right, [choose a different type](https://github.com/deepmodeling/dpgen/issues/new/choose).
title: "[BUG] _Replace With Suitable Title_"
labels: bug
assignees: ''

---

**Summary**

<!--Please provide a clear and concise description of what the bug is.-->

**DPGEN Version and Platform**

<!--Please specify precisely which DPGEN version this issue was detected with ("import dpgen" in the python command line interface and type "print(dpgen.__version__)") and what platform (operating system and its version, hardware) you are running on.-->

**Job submission and computing cluster configuration**

<!--If the question is about job submission, Please specify your jobs submission system and your authority. If applicable, specify your computing system configurations as well.-->

**Expected Behavior**

<!--Describe the expected behavior.  Quote from the DPGEN manual where needed, or explain why the expected behavior is meaningful, especially when it differs from the manual-->

**Actual Behavior**

<!--Describe the actual behavior, how it differs from the expected behavior, and how this can be observed.  Try to be specific and do **not** use vague terms like "doesn't work" or "wrong result".  Do not assume that the person reading this has any experience with or knowledge of your specific area of research.-->

**Steps to Reproduce**

<!--Describe the steps required to (quickly) reproduce the issue. You can attach (small) files to the section below or add URLs where to download an archive with all necessary files. Please try to create an input set that is as minimal and small as possible and reproduces the bug as quickly as possible. **NOTE:** the less effort and time it takes to reproduce your reported bug, the more likely it becomes, that somebody will look into it and fix the problem.-->

**Further Information, Files, and Links**

<!--Put any additional information here, attach relevant text or image files and URLs to external sites, e.g. relevant publications-->
